@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2003';
+our $VERSION = '0.2004';
 
 use Music::Duration;
 
@@ -430,6 +430,8 @@ sub combinatorial {
         1 => sub { $self->note( $opts->{duration}, $instrument ) },
     };
 
+    my $size = dura_size( $opts->{duration} );
+
     my @items = $opts->{patterns}
         ? $opts->{patterns}->@*
         : sort map { join '', @$_ }
@@ -441,7 +443,7 @@ sub combinatorial {
         for ( 1 .. $opts->{repeat} ) {
             for my $bit ( split //, $pattern ) {
                 $opts->{vary}{$bit}->();
-                $self->counter( $self->counter + dura_size( $opts->{duration} ) );
+                $self->counter( $self->counter + $size );
             }
         }
     }
@@ -461,7 +463,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2003
+version 0.2004
 
 =head1 SYNOPSIS
 
@@ -811,8 +813,8 @@ the file name.
   $d->steady( $d->kick, { duration => $d->eighth } );
 
 Play a steady beat with the given B<instrument> and optional
-B<duration> option, for the number of beats accumulated in the
-object's B<counter> attribute.
+B<duration>, for the number of beats accumulated in the object's
+B<counter> attribute.
 
 Defaults:
 
@@ -832,8 +834,8 @@ L<Algorithm::Combinatorics/variations_with_repetition>.
 This method accumulates beats in the object's B<counter> attribute.
 
 The B<vary> option is a hashref of coderefs, keyed by single character
-tokens, like the digits, 0-9.  The coderefs should add up to the
-B<duration> option.
+tokens, like the digits, 0-9.  The coderef durations should add up to
+the B<duration> option.
 
 Defaults:
 
